"use strict";
var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
Object.defineProperty(exports, "__esModule", { value: true });
var elmer_common_1 = require("elmer-common");
var elmer_ui_core_1 = require("elmer-ui-core");
var TypeCodeEditor_1 = require("./TypeCodeEditor");
var CodeEditorModel = (function (_super) {
    __extends(CodeEditorModel, _super);
    function CodeEditorModel(dom) {
        var _this = _super.call(this) || this;
        _this.lineData = [];
        var config = window[TypeCodeEditor_1.CODE_EDITOR_PLUGIN_CONFIG_KEY] || {};
        if (config[dom.props.language]) {
            var ComplilePlugin = config[dom.props.language].plugin;
            _this.highLight = config[dom.props.language].highLight;
            if (typeof ComplilePlugin === "function") {
                _this.complile = new ComplilePlugin();
            }
        }
        _this.dom = dom;
        _this.isEdit = dom.props.isEdit;
        return _this;
    }
    CodeEditorModel.prototype.setEditorContainer = function (div) {
        this.editorContainer = div;
    };
    CodeEditorModel.prototype.convertTextToLineData = function (txt) {
        var resultData = [];
        var lineData = [];
        var lineArr = (txt || "").split(/[\r\n]/);
        var lineHeight = this.dom.props.lineHeight;
        lineArr.map(function (lineStr) {
            resultData.push({
                index: resultData.length + 1,
                source: lineStr
            });
            lineData.push({
                key: lineData.length,
                index: resultData.length,
                style: "min-height: " + lineHeight + "px;height: " + lineHeight + "px;line-height: " + lineHeight + "px;",
                className: ""
            });
        });
        this.lineData = lineData;
        return resultData;
    };
    CodeEditorModel.prototype.getLinesData = function () {
        var lineData = [];
        var lineHeight = this.dom.props.lineHeight;
        var style = "min-height: " + lineHeight + "px;line-height: " + lineHeight + "px;";
        for (var i = 0, mLen = this.editorContainer.children.length; i < mLen; i++) {
            var lineDomHeight = this.editorContainer.children[i].clientHeight;
            lineData.push({
                key: i,
                index: i + 1,
                style: style + "height:" + lineDomHeight + "px;",
                className: ""
            });
        }
        return lineData;
    };
    CodeEditorModel.prototype.addNewLine = function (currentLineDom) {
        var lineHeight = this.dom.props.lineHeight;
        var lineDom = document.createElement("div");
        var currentIndex = currentLineDom.getAttribute("data-index");
        var index = (parseInt(currentIndex, 10) + 1);
        var nextLine = currentLineDom.nextSibling;
        lineDom.className = "view-line";
        lineDom.setAttribute("style", "line-height:" + lineHeight + "px;min-height: " + lineHeight + "px;");
        lineDom.setAttribute("type", "line");
        lineDom.setAttribute("data-index", index.toString());
        lineDom.innerHTML = "<span></span>";
        lineDom.setAttribute("contentEditable", "true");
        this.$.removeClass(currentLineDom, "active");
        if (nextLine) {
            this.editorContainer.insertBefore(lineDom, nextLine);
            for (var i = index; i < this.editorContainer.children.length; i++) {
                var line = this.editorContainer.children[i];
                line.setAttribute("data-index", i.toString());
            }
        }
        else {
            this.editorContainer.appendChild(lineDom);
        }
        lineDom.focus();
    };
    CodeEditorModel.prototype.attachTextDataToDom = function (data) {
        var _this = this;
        if (data) {
            var lineHeight_1 = this.dom.props.lineHeight;
            var isCommentFlag_1 = false;
            data.map(function (lineData, index) {
                var lineDom = document.createElement("div");
                lineDom.className = "view-line";
                lineDom.setAttribute("style", "line-height:" + lineHeight_1 + "px;min-height: " + lineHeight_1 + "px;");
                lineDom.setAttribute("type", "line");
                lineDom.setAttribute("data-index", index);
                if (_this.isEdit) {
                    lineDom.setAttribute("contentEditable", "true");
                }
                _this.analyzeText(lineDom, lineData.source, isCommentFlag_1);
                _this.editorContainer.appendChild(lineDom);
            });
            isCommentFlag_1 = null;
        }
    };
    CodeEditorModel.prototype.analyzeText = function (viewLine, str, commentFlag) {
        var spaceMatch = str.match(/^([\s]{1,})/);
        var lineHeight = this.dom.props.lineHeight;
        var spanStyle = "line-height:" + lineHeight + "px;min-height: " + lineHeight + "px;";
        if (spaceMatch) {
            var sLen = spaceMatch[1].length;
            var spanNone = document.createElement("span");
            spanNone.className = "view-space";
            spanNone.innerHTML = "&nbsp;".repeat(sLen);
            spanNone.setAttribute("style", spanStyle);
            viewLine.appendChild(spanNone);
        }
        this.analyzeTextKeywords(viewLine, str.replace(/^\s*/, ""), spanStyle);
    };
    CodeEditorModel.prototype.analyzeTextKeywords = function (viewLine, str, style, isString, isComment) {
        var _this = this;
        if (!isString && !isComment) {
            if (/^\/\//.test(str)) {
                var sp = document.createElement("span");
                sp.textContent = str;
                sp.className = "view-comment";
                viewLine.appendChild(sp);
            }
            else if (/^\"/.test(str) || /\'/.test(str) || /^\`/.test(str)) {
                console.log("string line");
            }
            else {
                if (str.indexOf("\"") > 0 || str.indexOf("'") > 0) {
                }
                else if (/\/\/[\s\S]{1,}$/.test(str)) {
                    var cMatch = str.match(/\/\/[\s\S]{1,}$/);
                    var commentValue = cMatch[0];
                    var notComment = str.substr(0, cMatch.index);
                    this.analyzeTextKeywords(viewLine, notComment, style, false, false);
                    var configClass = this.getValue(this.highLight, "comment.className");
                    var commentDom = this.createLineItemElement(commentValue, (!this.isEmpty(configClass) ? configClass : "view-comment"));
                    viewLine.appendChild(commentDom);
                }
                else {
                    var varArr = str.split(";");
                    if (varArr.length > 1) {
                        varArr.forEach(function (codeSplit, index) {
                            if (!_this.isEmpty(codeSplit)) {
                                if (/^\s{1,}$/.test(codeSplit)) {
                                    viewLine.appendChild(_this.createSpaceElement(codeSplit.length));
                                }
                                else {
                                    _this.analyzeTextKeywords(viewLine, codeSplit, style);
                                    viewLine.appendChild(_this.createLineItemElement(";", "view-split"));
                                }
                            }
                        });
                    }
                    else {
                        var keyReg = /^(\S{1,})(\s|$)/;
                        var lStr = str;
                        var keyMatch = str.match(keyReg);
                        while (keyMatch) {
                            var keyValue = keyMatch[1];
                            var keyClassName = this.findKeywordClassName(keyValue);
                            var keySpan = document.createElement("span");
                            keySpan.textContent = keyValue;
                            keySpan.setAttribute("style", style);
                            if (!this.isEmpty(keyClassName)) {
                                keySpan.className = keyClassName;
                            }
                            viewLine.appendChild(keySpan);
                            lStr = lStr.replace(/^(\S{1,})/, "");
                            var spMatch = lStr.match(/^\s{1,}/);
                            if (spMatch) {
                                viewLine.appendChild(this.createSpaceElement(spMatch[0].length));
                            }
                            lStr = lStr.replace(keyReg, "");
                            lStr = lStr.replace(/^\s{1,}/, "");
                            keyMatch = lStr.match(keyReg);
                        }
                    }
                }
            }
        }
    };
    CodeEditorModel.prototype.createLineItemElement = function (txt, className) {
        var span = document.createElement("span");
        var lineHeight = this.dom.props.lineHeight;
        var spanStyle = "line-height:" + lineHeight + "px;min-height: " + lineHeight + "px;";
        span.textContent = txt;
        span.className = className;
        span.setAttribute("style", spanStyle);
        return span;
    };
    CodeEditorModel.prototype.createSpaceElement = function (len) {
        var span = document.createElement("span");
        var lineHeight = this.dom.props.lineHeight;
        var spanStyle = "line-height:" + lineHeight + "px;min-height: " + lineHeight + "px;";
        span.innerHTML = "&nbsp;".repeat(len);
        span.setAttribute("style", spanStyle);
        return span;
    };
    CodeEditorModel.prototype.findKeywordClassName = function (keyword) {
        var _this = this;
        var resultClassName = "";
        if (this.highLight) {
            Object.keys(this.highLight).map(function (gKey) {
                var keyConfig = _this.highLight[gKey];
                if (keyConfig && _this.isArray(keyConfig.rules)) {
                    for (var _i = 0, _a = keyConfig.rules; _i < _a.length; _i++) {
                        var cKey = _a[_i];
                        if (_this.isRegExp(cKey)) {
                            if (cKey.test(keyword)) {
                                resultClassName = keyConfig.className;
                                break;
                            }
                        }
                        else {
                            if (cKey === keyword) {
                                resultClassName = keyConfig.className;
                                break;
                            }
                        }
                    }
                }
            });
        }
        return resultClassName;
    };
    __decorate([
        elmer_ui_core_1.autowired(elmer_ui_core_1.ElmerDOM),
        __metadata("design:type", elmer_ui_core_1.ElmerDOM)
    ], CodeEditorModel.prototype, "$", void 0);
    return CodeEditorModel;
}(elmer_common_1.Common));
exports.default = CodeEditorModel;
