"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.eAlert = exports.showInput = exports.createDialog = void 0;
var elmer_common_1 = require("elmer-common");
var elmer_ui_core_1 = require("elmer-ui-core");
var createDialog = function (options) {
    var ui = elmer_ui_core_1.getUI();
    var cOptions = {
        options: {
            visible: true
        },
        htmlCode: ""
    };
    var parent;
    ui.extend(cOptions, options);
    var result = {
        options: cOptions.options,
        show: function (updateOptions) {
            var cParams = JSON.parse(JSON.stringify(this.options));
            cParams.visible = true;
            if (options) {
                this.component.extend(cParams, updateOptions.options);
            }
            this.component.setData({
                options: cParams
            });
            cParams = null;
        },
        hide: function () {
            var cParams = JSON.parse(JSON.stringify(this.options));
            cParams.visible = false;
            this.component.setData({
                options: cParams
            });
            cParams = null;
        },
        setZIndex: function (index, visible) {
            var cParams = JSON.parse(JSON.stringify(this.options));
            cParams.zIndex = index;
            if (visible !== undefined && visible !== null) {
                cParams.visible = visible;
            }
            this.component.setData({
                options: cParams
            });
            this.zIndex = index;
            cParams = null;
        }
    };
    var dialogOwner = {
        options: ui.extend(cOptions.options, options.options),
        renderObj: null,
        container: parent,
        formID: ui.getRandomID(),
        removeFromContent: true,
        demoID: ui.getRandomID(),
        timestamp: (new Date()).getTime(),
        events: options.events,
        onClose: function () {
            var closeCallBack = this.myEvents.onClose;
            var exData = this.attrs;
            if (!this.removeFromContent) {
                if (this.container && this.container.parentElement) {
                    this.container.parentElement.removeChild(this.container);
                }
            }
            else {
                var lContainer = this.isDOM(this.dom[this.formID]) ? this.dom[this.formID] : this.dom[this.formID].formDom;
                if (lContainer.parentElement) {
                    lContainer.parentElement.removeChild(lContainer);
                }
                else {
                    console.error("Get wrong object to do the delete action");
                }
            }
            this.renderObj.dispose();
            this.renderObj = null;
            Object.keys(result).map(function (tmpKey) {
                delete result[tmpKey];
            });
            delete this.renderObj;
            delete this.container;
            delete this.myEvents;
            delete this.attrs;
            typeof closeCallBack === "function" && closeCallBack(exData);
        },
        onMin: function () {
            var cParams = JSON.parse(JSON.stringify(this.options));
            cParams.visible = false;
            this.setData({
                options: cParams
            });
            cParams = null;
            typeof this.myEvents.onMin === "function" && this.myEvents.onMin(this.attrs);
        },
        onMax: function (isMax) {
            typeof this.myEvents.onMax === "function" && this.myEvents.onMax(isMax, this.attrs);
        },
        onFocus: function () {
            typeof this.myEvents.onFocus === "function" && this.myEvents.onFocus(this.attrs);
        },
        close: function () {
            var formObj = this.dom[this.formID];
            var formObj2 = this.dom[this.demoID];
            if (formObj2) {
                formObj2.btnClose();
            }
            else {
                formObj.btnClose();
            }
        }
    };
    if (ui.isDOM(cOptions.parent)) {
        parent = cOptions.parent;
        dialogOwner.removeFromContent = true;
    }
    else {
        parent = document.createElement("div");
        cOptions.options.position = "fixed";
        dialogOwner.removeFromContent = false;
        document.body.appendChild(parent);
    }
    dialogOwner.container = parent;
    dialogOwner.myEvents = {
        onClose: cOptions.onClose,
        onMax: cOptions.onMax,
        onMin: cOptions.onMin,
        onFocus: cOptions.onFocus
    };
    dialogOwner.attrs = cOptions.attrs;
    var htmlCode = "<eui-win-form id=\"{{formID}}\" et:onFocus=\"onFocus\" et:onMax=\"onMax\" et:onMin=\"onMin\" et:onClose=\"onClose\" ...=\"{{options}}\" attrs=\"{{attrs}}\" et:emit=\"options.emit\">" + cOptions.htmlCode + "</eui-win-form>";
    if (cOptions.showMask) {
        htmlCode = "<div id=\"{{formID}}\" et:onFocus=\"onFocus\" em:show='this.options.visible' class='elmerDialog'>\n            <div><eui-win-form timestamp=\"{{timestamp}}\" id=\"{{demoID}}\" et:emit=\"options.emit\" attrs=\"{{attrs}}\" et:onMax=\"onMax\" et:onMin=\"onMin\" et:onClose=\"onClose\" ...=\"{{options}}\">\n                <ChildrenWrapperContent>" + cOptions.htmlCode + "</ChildrenWrapperContent>\n                <ChildrenWrapperBottom>" + cOptions.options.bottom + "</ChildrenWrapperBottom>\n            </eui-win-form></div></div>";
    }
    result.render = ui.render(parent, htmlCode, dialogOwner);
    result.component = dialogOwner;
    result.options = cOptions.options;
    result.zIndex = cOptions.options.zIndex;
    result.setData = function (data, refresh) {
        dialogOwner.setData(__assign(__assign({}, data), { timestamp: (new Date()).getTime() }), refresh);
        var form = dialogOwner.dom[dialogOwner.demoID];
        form.setState({}, true);
    };
    result.setState = function (state, refresh) {
        dialogOwner.setState(state, refresh);
    };
    dialogOwner.renderObj = result.render;
    ui = null;
    cOptions = null;
    return result;
};
exports.createDialog = createDialog;
var showInput = function (options) {
    var config = {
        title: "输入框",
        placeHolder: "请输入",
        okText: "确定",
        cancelText: "取消",
        defaultValue: "",
        zIndex: 1000
    };
    var isConfirm = false;
    var inputValue = "";
    elmer_common_1.StaticCommon.extend(config, options);
    return exports.createDialog({
        showMask: true,
        options: {
            title: config.title,
            zIndex: config.zIndex,
            showBarMax: false,
            showBarMin: false,
            showIcon: false,
            showBottom: true,
            bottom: "<button evt:click='props.emit' class='alert-yes'>" + config.okText + "</button><button evt:click='props.emit' class='alert-no'>" + config.cancelText + "</button>",
            bottomTheme: "elmerAlertTwoButton elmerAlertButton",
            emit: function (evt) {
                if (evt.target.tagName === "BUTTON") {
                    isConfirm = /alert\-yes/i.test(evt.target.className);
                    if (isConfirm) {
                        if (typeof config.onBefore === "function") {
                            var exEvent = __assign(__assign({}, evt), { cancel: false, value: inputValue });
                            config.onBefore(exEvent);
                            if (exEvent.cancel) {
                                return;
                            }
                        }
                    }
                    this.close();
                }
                else if (evt.target.tagName === "INPUT") {
                    inputValue = evt.target.value;
                }
            }
        },
        htmlCode: "<div style=\"padding: 20px 10px;\"><input et:keyup=\"options.emit\" type='text' class='eui-input' placeholder=\"" + config.placeHolder + "\"/></div>",
        onClose: function () {
            if (isConfirm) {
                typeof config.onOk === "function" && config.onOk(inputValue);
            }
            else {
                typeof config.onCancel === "function" && config.onCancel();
            }
        }
    });
};
exports.showInput = showInput;
var eAlert = function (options) {
    var config = {
        message: "",
        okText: "确定",
        cancelText: "取消",
        retryText: "重试",
        okTheme: "eui-button-primary",
        cancelTheme: "",
        retryTheme: "",
        zIndex: 1000,
        showTipIcon: true
    };
    elmer_common_1.StaticCommon.extend(config, options);
    var noTipTheme = !config.showTipIcon ? "elmerAlertNoTipIcon" : "";
    var bottomCode = "";
    var bottomTheme = "";
    var choseButton = "None";
    if ((config.msgType === "OKOnly" || config.msgType === "YesOnly")) {
        bottomCode = "<button evt:click='options.emit' class='alert-yes " + config.okTheme + "'>" + config.okText + "</button>";
        bottomTheme = "elmerAlertOneButton";
    }
    else if (["OkCancel", "YesNo"].indexOf(config.msgType) > -1) {
        bottomCode = "<button evt:click='options.emit' class='alert-yes " + config.okTheme + "'>" + config.okText + "</button><button evt:click='options.emit' class='alert-no " + config.cancelTheme + "'>" + config.cancelText + "</button>";
        bottomTheme = "elmerAlertTwoButton";
    }
    else if (["OkCancelRetry", "YesNoRetry"].indexOf(config.msgType) > -1) {
        bottomCode = "<button evt:click='options.emit' class='alert-yes " + config.okTheme + "'>" + config.okText + "</button><button evt:click='options.emit' class='alert-no " + config.cancelTheme + "'>" + config.cancelText + "</button><button evt:click='props.emit' class='alert-try " + config.retryTheme + "'>" + config.retryText + "</button>";
        bottomTheme = "elmerAlertThreeButton";
    }
    else {
        bottomCode = "<button evt:click='options.emit' class='alert-yes " + config.okTheme + "'>" + config.okText + "</button>";
        bottomTheme = "elmerAlertOneButton";
    }
    bottomTheme = "elmerAlertButton " + bottomTheme;
    return exports.createDialog({
        showMask: true,
        attrs: config.attrs,
        events: config.events,
        options: {
            title: config.title || "提示",
            showBottom: true,
            showIcon: false,
            showBarMin: false,
            showBarMax: false,
            bottomTheme: bottomTheme,
            bottom: bottomCode,
            zIndex: config.zIndex,
            theme: (config.iconType || "") + " eui-Alert " + (config.isMobile ? "eui-Alert-mobile" : ""),
            visible: true,
            events: config.events,
            emit: function (evt) {
                var button = evt.target;
                var clickButton = "None";
                var beforeEvent = {
                    button: "None",
                    cancel: false
                };
                if (/alert\-yes/.test(button.className)) {
                    choseButton = "Ok";
                    clickButton = "Ok";
                }
                else if (/alert\-no/.test(button.className)) {
                    choseButton = "Cancel";
                    clickButton = "Cancel";
                }
                else if (/alert\-try/.test(button.className)) {
                    choseButton = "Retry";
                    clickButton = "Retry";
                }
                else {
                    choseButton = "Cancel";
                    clickButton = "Cancel";
                }
                button = null;
                if (typeof config.onBefore === "function") {
                    beforeEvent.button = clickButton;
                    config.onBefore(beforeEvent);
                }
                if (!beforeEvent.cancel) {
                    this.close();
                }
            }
        },
        htmlCode: elmer_common_1.StaticCommon.isEmpty(config.content) ? "<div class=\"elmerAlertContent " + noTipTheme + "\"><div>" + config.message + "</div></div>" : config.content,
        onClose: function () {
            if (choseButton === "Ok") {
                typeof config.onOk === "function" && config.onOk();
            }
            else if (choseButton === "Cancel") {
                typeof config.onCancel === "function" && config.onCancel();
            }
            else if (choseButton === "Retry") {
                typeof config.onRetry === "function" && config.onRetry();
            }
            else {
                typeof config.onCancel === "function" && config.onCancel();
            }
        }
    });
};
exports.eAlert = eAlert;
if (!window["eAlert"]) {
    elmer_ui_core_1.defineGlobalVar("eAlert", exports.eAlert);
}
if (!window["createDialog"]) {
    elmer_ui_core_1.defineGlobalVar("createDialog", exports.createDialog);
}
exports.default = {
    open: exports.createDialog,
    input: exports.showInput,
    alert: exports.eAlert
};
