"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createRegionPicker = void 0;
var elmer_ui_core_1 = require("elmer-ui-core");
var RegionData_1 = require("./RegionData");
var createRegionPicker = function (options) {
    var config = {
        data: RegionData_1.RegionData,
        provinceTitle: "省份",
        cityTitle: "城市",
        districtTitle: "县区",
        provinceData: RegionData_1.RegionData.noCategoryProvince,
        defaultValue: [],
        title: ""
    };
    var ui = elmer_ui_core_1.getUI();
    var parent = document.createElement("div");
    ui.extend(config, options);
    var provinceData = JSON.parse(JSON.stringify(config.provinceData || []));
    provinceData.splice(0, 0, {
        title: config.provinceTitle,
        value: -1,
        disabled: true
    });
    var obj = {
        visible: false,
        data: [provinceData],
        provinceKey: -1,
        cityKey: -1,
        defaultIndex: [],
        config: config,
        handleOnClose: function () {
            this.setData({
                visible: false
            });
            typeof config.onClose === "function" && config.onClose();
        },
        handleOnOK: function (data) {
            typeof config.onSelected === "function" && config.onSelected(data);
        },
        handleOnChanged: function (data) {
            var tmpProvinceKey = data.selectedIndex[0];
            var tmpProvinceData = data.selectedItems[0];
            if (tmpProvinceKey !== this.provinceKey) {
                var tmpProvinceCode = tmpProvinceData.value;
                var cityData = JSON.parse(JSON.stringify(config.data[tmpProvinceCode] || []));
                var newData = JSON.parse(JSON.stringify(this.data || []));
                this.provinceKey = tmpProvinceKey;
                if (cityData.length > 0) {
                    cityData.splice(0, 0, {
                        title: config.cityTitle,
                        value: -1,
                        disabled: true
                    });
                    newData.splice(1, this.data.length - 1, cityData);
                }
                else {
                    newData.splice(1, this.data.length - 1);
                }
                this.setData({
                    data: newData
                });
            }
            else {
                var tmpCityKey = data.selectedIndex[1];
                var tmpCityData = data.selectedItems[1];
                if (this.cityKey !== tmpCityKey) {
                    var tmpCityCode = tmpCityData.value;
                    var districtData = JSON.parse(JSON.stringify(config.data[tmpCityCode] || []));
                    var newData = JSON.parse(JSON.stringify(this.data || []));
                    this.cityKey = tmpCityKey;
                    if (districtData.length > 0) {
                        districtData.splice(0, 0, {
                            title: config.districtTitle,
                            value: -1,
                            disabled: true
                        });
                        newData.splice(2, this.data.length - 2, districtData);
                    }
                    else {
                        newData.splice(2, this.data.length - 2);
                    }
                    this.setData({
                        data: newData
                    });
                }
            }
        },
        show: function () {
            obj.setData({
                visible: true
            });
        },
        hide: function () {
            obj.setData({
                visible: false
            });
        }
    };
    var initData = function () {
        var defaultValue = config.defaultValue || [];
        var tmpProvinceCode = defaultValue[0] || "";
        var tmpCityCode = defaultValue[1] || "";
        var tmpDistrictCode = defaultValue[2] || "";
        var updateData = [];
        var updateIndex = [];
        var cityData = [];
        var districtData = [];
        updateData.push(JSON.parse(JSON.stringify(provinceData)));
        if (!ui.isEmpty(tmpProvinceCode)) {
            for (var key = 0; key < provinceData.length; key++) {
                if (provinceData[key].value === tmpProvinceCode) {
                    cityData = config.data[tmpProvinceCode];
                    updateIndex.push(key);
                    obj.provinceKey = key;
                    break;
                }
            }
            if (!ui.isEmpty(tmpCityCode) && cityData.length > 0) {
                for (var key = 0; key < cityData.length; key++) {
                    if (cityData[key].value === tmpCityCode) {
                        districtData = config.data[tmpCityCode];
                        updateIndex.push(key);
                        obj.cityKey = key;
                        break;
                    }
                }
                updateData.push(JSON.parse(JSON.stringify(cityData)));
                if (!ui.isEmpty(tmpDistrictCode) && districtData.length > 0) {
                    for (var key = 0; key < districtData.length; key++) {
                        if (districtData[key].value === tmpDistrictCode) {
                            updateIndex.push(key);
                            break;
                        }
                    }
                    updateData.push(JSON.parse(JSON.stringify(districtData)));
                }
            }
        }
        obj.defaultIndex = updateIndex;
        obj.data = updateData;
    };
    initData();
    ui.render(parent, "<eui-mobile-select title='{{config.title}}' defaultValue='{{defaultIndex}}' data='{{data}}' visible='{{visible}}' et:onOk='handleOnOK' et:onClose='handleOnClose' et:onChange='handleOnChanged'/>", obj);
    document.body.appendChild(parent);
    return obj;
};
exports.createRegionPicker = createRegionPicker;
elmer_ui_core_1.defineGlobalVar("createRegionPicker", exports.createRegionPicker);
