"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var MatrixCharacterEffects = (function () {
    function MatrixCharacterEffects(cav) {
        this.objects = [];
        this.wordColor = "#33ff33";
        this.fontSize = 16;
        this.time = 0;
        this.canvas = cav;
        this.cvt = cav.getContext("2d");
    }
    MatrixCharacterEffects.prototype.init = function () {
        this.width = this.canvas.clientWidth;
        this.height = this.canvas.clientHeight;
        this.canvas.width = this.width;
        this.canvas.height = this.height;
        this.cvt.fillStyle = "#000";
        this.cvt.fillRect(0, 0, this.width, this.height);
        this.cvt.fill();
        this.cvt.save();
        this.refreshObjects();
    };
    MatrixCharacterEffects.prototype.dispose = function () {
        this.cvt = null;
        this.canvas = null;
    };
    MatrixCharacterEffects.prototype.onPropsChange = function (props) {
        throw new Error("Method not implemented.");
    };
    MatrixCharacterEffects.prototype.resize = function () {
        this.init();
    };
    MatrixCharacterEffects.prototype.draw = function () {
        if (this.time % 6 === 0) {
            var cvt = this.cvt;
            cvt.fillStyle = "rgba(0,0,0,0.4)";
            cvt.fillRect(0, 0, this.width, this.height);
            cvt.fill();
            cvt.save();
            cvt.beginPath();
            cvt.fillStyle = this.wordColor;
            cvt.font = this.fontSize + "px Courier New";
            for (var i = 0, mLen = this.objects.length; i < mLen; i++) {
                var tmpObj = this.objects[i];
                var dStr = tmpObj.text;
                for (var j = 0, xLen = dStr.length; j < xLen; j++) {
                    cvt.fillText(dStr.substr(j, 1), tmpObj.x, tmpObj.y + j * this.fontSize + 2);
                }
                if (this.objects[i].y + tmpObj.speed < this.height) {
                    this.objects[i].y = this.objects[i].y + tmpObj.speed + 1;
                }
                else {
                    this.objects[i].y = parseInt((-Math.random() * this.height / 2).toString(), 10) + 1;
                    this.objects[i].text = this.getSupportStr();
                }
                dStr = null;
                tmpObj = null;
            }
            cvt.fill();
            cvt.save();
            cvt.restore();
            cvt = null;
            this.time = 0;
        }
        this.time += 1;
    };
    MatrixCharacterEffects.prototype.refreshObjects = function () {
        var columnLen = this.width / (this.fontSize / 2);
        this.objects = [];
        for (var i = 0; i < columnLen; i++) {
            this.objects.push({
                x: i * this.fontSize,
                y: parseInt((Math.random() * this.height).toString(), 10) + 1,
                speed: Math.random() + 50,
                text: this.getSupportStr(),
                duration: 3
            });
        }
    };
    MatrixCharacterEffects.prototype.getSupportStr = function () {
        var baseStr = "ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789アイウエオカキクケコトテツタソセシササナニヌノヒヘホマミメヤヨラルロヲㅥㅧㅧㄆㄈㄓㄥㄣㄢㄠㄝㄧㄩ";
        var len = baseStr.length;
        var dataLen = parseInt((Math.random() * 20 + 5).toString(), 10);
        var result = "";
        for (var i = 0; i < dataLen; i++) {
            var index = parseInt((Math.random() * len).toString(), 10);
            result += baseStr.substr(index, 1);
            index = null;
        }
        dataLen = null;
        len = null;
        baseStr = null;
        return result;
    };
    return MatrixCharacterEffects;
}());
exports.MatrixCharacterEffects = MatrixCharacterEffects;
