"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createModuleConfig = exports.createUserGroupColumns = void 0;
var components_1 = require("../../../components");
var dataView_1 = require("../../../components/office/widget/dataView");
var createUserGroupColumns = function () {
    var _this = this;
    return dataView_1.createOfficeDataViewHeader([
        [
            {
                title: "<div>\n                    <eui-button theme='eui-button-primary' et:onClick='props.events.onAddGroup'>\u65B0\u589E</eui-button>\n                    <eui-button et:onClick='props.events.onRefresh' style=\"margin-left: 5px;\">\u5237\u65B0</eui-button>\n                </div>",
                colspan: 6,
                isCodeTitle: true,
                className: "UserGroupOperation",
                events: {
                    onAddGroup: function () {
                        _this.handleOnAddGroup();
                    },
                    onRefresh: this.loadGroupList.bind(this)
                }
            }
        ],
        [
            {
                title: "分组ID",
                dataKey: "id",
                style: "width:60px;"
            }, {
                title: "分组名称",
                dataKey: "name"
            },
            {
                title: "是否超级管理员",
                dataKey: "isSuper",
                render: function (isSuper) {
                    return "<span>" + (isSuper ? "是" : "否") + "</span>";
                }
            },
            {
                title: "创建人",
                dataKey: "createUser"
            }, {
                title: "创建时间",
                dataKey: "createTime",
                style: "width:140px;padding: 5px;"
            },
            {
                title: "操作",
                dataKey: "id",
                style: "width: 200px;",
                events: {
                    onSetRights: function (evt) {
                        var choseGroupId = _this.getValue(_this.state, "choseGroup.id");
                        if (evt.data.id !== choseGroupId) {
                            var loading_1 = components_1.showLoading({ title: "获取权限" });
                            var handler = setTimeout(function () {
                                _this.getGroupModule(evt.data.id).then(function () {
                                    _this.setState({
                                        choseGroup: evt.data,
                                        groupName: "(" + evt.data.name + ")",
                                        tabIndex: 1,
                                        timestamp: (new Date()).getTime()
                                    });
                                    _this.dom[_this.tabId].switchTab(1);
                                    loading_1.dispose();
                                }).catch(function () {
                                    loading_1.dispose();
                                });
                            }, 200);
                        }
                    },
                    onEditGroup: function (evt) {
                        _this.handleOnAddGroup(evt.data);
                    },
                    onDelGroup: function (evt) {
                        components_1.eAlert({
                            title: "提示",
                            message: "\u8BF7\u6CE8\u610F\u5220\u9664\u5206\u7EC4\u3010" + evt.data.name + "\u3011\u5DF2\u7ECF\u8BBE\u7F6E\u597D\u7684\u6743\u9650\u5C06\u4E22\u5931\u65E0\u6CD5\u6062\u590D\u53EA\u80FD\u91CD\u65B0\u6388\u6743\u3002",
                            msgType: "OkCancel",
                            iconType: "Information",
                            onOk: function () {
                                _this.delUserGroup(evt.data.id);
                            }
                        });
                    }
                },
                render: function (id, data) {
                    return "<eui-button data=\"{{props.data}}\" et:onClick=\"props.events.onSetRights\" theme=\"eui-button-primary\" title=\"\u6388\u6743\"/>\n                        <eui-button style=\"margin-left: 5px;\" title=\"\u5220\u9664\" data=\"{{props.data}}\" et:onClick=\"props.events.onDelGroup\"/>\n                        <eui-button style=\"margin-left: 5px;\" title=\"\u4FEE\u6539\" data=\"{{props.data}}\" et:onClick=\"props.events.onEditGroup\"/>";
                }
            }
        ]
    ]);
};
exports.createUserGroupColumns = createUserGroupColumns;
var createModuleConfig = function () {
    var _this = this;
    var resultData = dataView_1.createOfficeDataViewHeader([[
            {
                title: "授权",
                dataKey: "id",
                style: "width: 60px;",
                events: {
                    onAuthRightClick: function (evt) {
                        _this.setGroupRight(evt.data.module, evt.checked);
                    }
                },
                render: function (id, data) {
                    var groupRight = _this.getValue(_this, "state.groupRight");
                    var hasRight = false;
                    if (groupRight && groupRight.length > 0) {
                        for (var i = 0; i < groupRight.length; i++) {
                            var rightItem = groupRight[i];
                            if (rightItem.module === data.module && rightItem.moduleId === id) {
                                hasRight = true;
                                break;
                            }
                        }
                    }
                    var checked = hasRight ? "true" : "false";
                    return "<eui-checkbox data-module=\"{{props.data}}\" checked=\"{{" + checked + "}}\" et:onChange=\"props.events.onAuthRightClick\"/>";
                }
            },
            {
                title: "模块名称",
                dataKey: "title",
                style: "text-align:left;",
                render: function (title, data) {
                    return "<span data-type=\"html\">" + data.prefix + title + "</span>";
                }
            },
            {
                title: "路径",
                dataKey: "url",
                style: "text-align:left;",
            }, {
                title: "图标",
                dataKey: "icon"
            }
        ]]);
    return resultData;
};
exports.createModuleConfig = createModuleConfig;
