"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createUserGroupColumns = exports.createUserColumns = void 0;
var components_1 = require("../../../components");
var dataView_1 = require("../../../components/office/widget/dataView");
var createUserColumns = function () {
    var _this = this;
    return dataView_1.createOfficeDataViewHeader([
        [
            {
                title: "<div>\n                    <eui-button theme='eui-button-primary' et:onClick='props.events.onAddUser'>\u65B0\u589E</eui-button>\n                    <eui-button et:onClick='props.events.onRefresh' style=\"margin-left: 5px;\">\u5237\u65B0</eui-button>\n                </div>",
                colspan: 6,
                isCodeTitle: true,
                className: "UserGroupOperation",
                events: {
                    onAddUser: function () {
                        _this.handleOnAddUser();
                    },
                    onRefresh: this.loadUserList.bind(this)
                }
            }
        ],
        [
            { title: "用户ID", dataKey: "id", style: "width:50px;" },
            { title: "登录账号", dataKey: "userLogin" },
            { title: "昵称", dataKey: "userName" },
            { title: "头像", dataKey: "header", render: function (header) {
                    return !_this.isEmpty(header) ? "<img style=\"width:50px;height:50px;\" src=\"" + header + "\" />" : "<span>未上传头像</span>";
                } },
            { title: "状态", dataKey: "status",
                style: "width: 50px", render: function (status) {
                    return status === 1 ? "<span>正常</span>" : "<span style='color: gray;'>已禁用</span>";
                }
            }, {
                title: "操作",
                dataKey: "id",
                style: "width: 200px;",
                events: {
                    onDelete: function (evt) {
                        var userData = evt.data;
                        if (userData.userLogin !== "admin") {
                            components_1.eAlert({
                                title: "提示",
                                message: "\u786E\u5B9A\u5220\u9664\u5F53\u524D\u7BA1\u7406\u5458\uFF1F",
                                msgType: "OkCancel",
                                iconType: "Question",
                                onOk: function () {
                                    _this.onDeleteUser(userData.id);
                                }
                            });
                        }
                        else {
                            components_1.eAlert({
                                title: "提示",
                                message: "admin\u4E3A\u7CFB\u7EDF\u9ED8\u8BA4\u7BA1\u7406\u5458\u4E0D\u80FD\u5220\u9664\uFF01",
                                iconType: "Information"
                            });
                        }
                    },
                    onCheckGroup: function (evt) {
                        var oldId = _this.getValue(_this.state, "choseUser.id");
                        if (evt.data.id !== oldId) {
                            _this.getUserGroupByUser(evt.data.id).then(function (groupList) {
                                var userName = !_this.isEmpty(evt.data.userName) ? evt.data.userName : evt.data.userLogin;
                                _this.setState({
                                    choseUser: evt.data,
                                    choseUserName: " (" + userName + ")",
                                    choseUserGroup: groupList
                                });
                                _this.dom[_this.tabId].switchTab(1);
                            });
                        }
                        else {
                            if (_this.state.choseUser) {
                                _this.dom[_this.tabId].switchTab(1);
                            }
                        }
                    },
                    onEdit: function (evt) {
                        _this.handleOnAddUser(evt.data);
                    }
                },
                render: function (id, data) {
                    return "<eui-button data=\"{{props.data}}\" theme=\"eui-button-primary\" et:onClick=\"props.events.onCheckGroup\">\u7528\u6237\u7EC4</eui-button>\n                    <eui-button data=\"{{props.data}}\" et:onClick=\"props.events.onEdit\" style=\"margin-left: 5px;\">\u4FEE\u6539</eui-button>\n                    <eui-button data=\"{{props.data}}\" et:onClick=\"props.events.onDelete\" style=\"margin-left: 5px;\">\u5220\u9664</eui-button>\n                ";
                }
            }
        ]
    ]);
};
exports.createUserColumns = createUserColumns;
var createUserGroupColumns = function () {
    var _this = this;
    return dataView_1.createOfficeDataViewHeader([[
            {
                title: "选择",
                style: "width: 50px;",
                dataKey: "id",
                events: {
                    onChange: function (evt) {
                        _this.updateUserForGroupDetail(evt.data.group.id, _this.state.choseUser.id, evt.checked)
                            .then(function () {
                            _this.getUserGroupByUser(_this.state.choseUser.id).then(function (groupList) {
                                _this.setState({
                                    choseUserGroup: groupList
                                });
                            });
                        });
                    }
                },
                render: function (id, data) {
                    var userGroupList = _this.state.choseUserGroup || [];
                    var checked = "false";
                    for (var key in userGroupList) {
                        var item = userGroupList[key];
                        if (item.groupId === id) {
                            checked = "true";
                            break;
                        }
                    }
                    return "<eui-checkbox data-group=\"{{props.data}}\" et:onChange=\"props.events.onChange\" checked='{{" + checked + "}}'/>";
                }
            },
            {
                title: "分组",
                dataKey: "name"
            },
            {
                title: "是否超级管理员",
                dataKey: "isSuper",
                render: function (isSuper) {
                    return isSuper === 1 ? "<span>是</span>" : "<span>否</span>";
                }
            }
        ]]);
};
exports.createUserGroupColumns = createUserGroupColumns;
