"use strict";
var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (Object.prototype.hasOwnProperty.call(b, p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        if (typeof b !== "function" && b !== null)
            throw new TypeError("Class extends value " + String(b) + " is not a constructor or null");
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
Object.defineProperty(exports, "__esModule", { value: true });
exports.PictureBackground = void 0;
var elmer_common_1 = require("elmer-common");
var PictureBackground = (function (_super) {
    __extends(PictureBackground, _super);
    function PictureBackground(cav, props) {
        var _this = _super.call(this) || this;
        _this.imageLink = "";
        _this.blur = 10;
        _this.fillBackColor = "rgb(235, 235, 235)";
        _this.canvas = cav;
        _this.cvt = cav.getContext("2d");
        _this.imageLink = _this.getValue(props, "backgroundConfig.image");
        _this.blur = _this.getValue(props, "backgroundConfig.blur");
        _this.fillBackColor = _this.getValue(props, "backgroundConfig.backgroundColor") || "rgb(235, 235, 235)";
        return _this;
    }
    PictureBackground.prototype.init = function () {
        this.width = this.canvas.clientWidth;
        this.height = this.canvas.clientHeight;
        this.canvas.width = this.width;
        this.canvas.height = this.height;
        this.fillBack();
        this.downloadImage();
    };
    PictureBackground.prototype.dispose = function () {
        this.cvt = null;
        this.canvas = null;
    };
    PictureBackground.prototype.onPropsChange = function (props) {
        var img = this.getValue(props, "backgroundConfig.image");
        var blur = this.getValue(props, "backgroundConfig.blur");
        if ((!this.isEmpty(img) && img !== this.imageLink) || blur !== this.blur) {
            if (blur !== this.blur) {
                this.blur = blur >= 0 ? blur : 0;
            }
            if ((!this.isEmpty(img) && img !== this.imageLink)) {
                this.imageLink = img;
                this.downloadImage();
            }
            else {
                this.draw();
            }
        }
    };
    PictureBackground.prototype.draw = function (tim) {
        if (this.image) {
            this.fillBack();
            this.cvt.drawImage(this.image, 0, 0, this.width, this.height);
            this.drawBlur();
        }
    };
    PictureBackground.prototype.resize = function (wWidth, wHeight) {
        this.width = this.canvas.clientWidth;
        this.height = this.canvas.clientHeight;
        this.canvas.width = this.width;
        this.canvas.height = this.height;
        this.draw();
    };
    PictureBackground.prototype.fillBack = function () {
        this.cvt.fillStyle = this.fillBackColor;
        this.cvt.fillRect(0, 0, this.width, this.height);
        this.cvt.fill();
        this.cvt.save();
    };
    PictureBackground.prototype.downloadImage = function () {
        var _this = this;
        if (!this.isEmpty(this.imageLink)) {
            var img_1 = new Image();
            img_1.onload = function () {
                _this.image = img_1;
                _this.draw();
            };
            img_1.src = this.imageLink;
        }
    };
    PictureBackground.prototype.drawBlur = function () {
        if (this.height) {
            var imgData = this.cvt.getImageData(0, 0, this.width, this.height);
            var blurData = this.gaussBlur(imgData);
            this.cvt.putImageData(blurData, 0, 0);
        }
    };
    PictureBackground.prototype.gaussBlur = function (imgData) {
        var pixes = imgData.data;
        var width = imgData.width;
        var height = imgData.height;
        var gaussMatrix = [], gaussSum = 0, x, y, r, g, b, a, i, j, k;
        var radius = 10;
        var sigma = 5;
        a = 1 / (Math.sqrt(2 * Math.PI) * sigma);
        b = -1 / (2 * sigma * sigma);
        for (var i_1 = 0, x_1 = -radius; x_1 <= radius; x_1++, i_1++) {
            g = a * Math.exp(b * x_1 * x_1);
            gaussMatrix[i_1] = g;
            gaussSum += g;
        }
        for (var i_2 = 0, len = gaussMatrix.length; i_2 < len; i_2++) {
            gaussMatrix[i_2] /= gaussSum;
        }
        for (y = 0; y < height; y++) {
            for (x = 0; x < width; x++) {
                r = g = b = a = 0;
                gaussSum = 0;
                for (j = -radius; j <= radius; j++) {
                    k = x + j;
                    if (k >= 0 && k < width) {
                        i = (y * width + k) * 4;
                        r += pixes[i] * gaussMatrix[j + radius];
                        g += pixes[i + 1] * gaussMatrix[j + radius];
                        b += pixes[i + 2] * gaussMatrix[j + radius];
                        gaussSum += gaussMatrix[j + radius];
                    }
                }
                i = (y * width + x) * 4;
                pixes[i] = r / gaussSum;
                pixes[i + 1] = g / gaussSum;
                pixes[i + 2] = b / gaussSum;
            }
        }
        for (x = 0; x < width; x++) {
            for (y = 0; y < height; y++) {
                r = g = b = a = 0;
                gaussSum = 0;
                for (j = -radius; j <= radius; j++) {
                    k = y + j;
                    if (k >= 0 && k < height) {
                        i = (k * width + x) * 4;
                        r += pixes[i] * gaussMatrix[j + radius];
                        g += pixes[i + 1] * gaussMatrix[j + radius];
                        b += pixes[i + 2] * gaussMatrix[j + radius];
                        gaussSum += gaussMatrix[j + radius];
                    }
                }
                i = (y * width + x) * 4;
                pixes[i] = r / gaussSum;
                pixes[i + 1] = g / gaussSum;
                pixes[i + 2] = b / gaussSum;
            }
        }
        return imgData;
    };
    return PictureBackground;
}(elmer_common_1.Common));
exports.PictureBackground = PictureBackground;
